Internal function to carry out the bootstrap ; It is a sub-module of summary.rqcan; not intended for general use.
The parameters may be passed by summary.rqcan (see below)
boot.can(
a,
Rep = 200,
method = "Andrews",
msub = 0.9,
seed,
nsing = 5,
prb = FALSE
)Returns list(As, Bs, sdc): As (Bs) are N by dim(alpha) (dim(beta)) arrays of all bootstrap alphs and beta values; sdc = sqrt(m/n): SD adjustment for m-choose-n bootstrap, or 1 for "xy" bootstrap
output from rqcan
number of bootstrap replications (default=200)
"Andrews" (default) or ""xy"
parameter defining the size of the bootstrap subsample for developmental work only: see the boot.can function
a starting seed (default: missing: no new seed set)
number of consecutive singular replicatios to ignore (default = 5)
if TRUE (default = FALSE), print every time 10 percent of the bootstrap samples are done
See help(summary.rqcan) ; If errors occur or modification is wanted, see the routine boot.can